# fyda - The "interface For Your DAta"

## Features

Easily interact with your data using as little python code as possible. Control
the available data in the ``input`` folder, and use fyda's built-in api to
load it, transform it, and model it. 


## Installation

```sh
pip install fyda
```


## User guide

You should [Read The Docs](https://fyda.readthedocs.io/en/latest/) for all
the goodies!
